'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var cluster = _interopDefault(require('cluster'));
var os = _interopDefault(require('os'));
var processName = require('./process-name.js');
var logFactory = require('./log-factory.js');

const calculateOptions = options => ({
  numberOfWorkers:
    process.env.EXPRESS_CLUSTER_NUMBER_OF_WORKERS || os.cpus().length,
  handleUncaughtException:
    process.env.EXPRESS_CLUSTER_HANDLE_UNCAUGHT_EXCEPTION !== 'false',
  workerRespawnDelay: process.env.EXPRESS_CLUSTER_WORKER_RESPAWN_DELAY || 1000,
  workerKillTimeout: process.env.EXPRESS_CLUSTER_WORKER_KILL_TIMEOUT || 30000,
  logLevel: process.env.EXPRESS_CLUSTER_LOG_LEVEL || 'info',
  ...options,
});

const log = logFactory.default(calculateOptions().logLevel);

var clusterStability = async (workerFunction, options = {}, masterFunction) => {
  if (typeof workerFunction !== 'function') {
    throw new Error('workerFunction must be supplied as the first argument.')
  }
  if (typeof options !== 'object') {
    throw new Error(
      'The second argument, if supplied, must be an options object, null or undefined.'
    )
  } else if (
    options !== null &&
    typeof options === 'object' &&
    typeof options.length !== 'undefined'
  ) {
    throw new Error(
      'The second argument, if supplied, must be an options object or null.'
    )
  }
  if (
    typeof masterFunction !== 'undefined' &&
    typeof masterFunction !== 'function'
  ) {
    throw new Error(
      'The third argument, if supplied, must be the masterFunction.'
    )
  }

  const effectiveOptions = calculateOptions(options);
  effectiveOptions.log = logFactory.default(
    effectiveOptions.logLevel,
    effectiveOptions.logger
  );
  if (cluster.isMaster) {
    const clusterMaster = (await Promise.resolve().then(function () { return require('./cluster-master/index.js'); })).default;
    clusterMaster(masterFunction, effectiveOptions);
  } else {
    const clusterWorker = (await Promise.resolve().then(function () { return require('./cluster-worker/index.js'); })).default;
    clusterWorker(workerFunction, effectiveOptions);
  }
};

exports.processName = processName.default;
exports.default = clusterStability;
exports.log = log;

if(exports.default&&["object","function"].includes(typeof exports.default)){Object.assign(exports.default,exports);exports.default.default=module.exports=exports.default}
